@@ -1,15 +1,14 @@
-#coding=utf-8
 # -*- coding:utf-8 -*-
 
 from ..util import client, formater, list2table, result_cache, it
-from terminal import bold, magenta, white, blue, green,red, yellow, confirm
+from terminal import bold, magenta, white, blue, green,red, yellow
 from ..const import CMD
 
 PROGRESS_LEN = 70
 
-def all(clusterId=None):
+def all(clusterId=None, description=False, log=False):
     if clusterId:
-        get(clusterId)
+        get(clusterId, description, log)
     else:
         list()
 
@@ -24,6 +23,9 @@ def list():
 
     arr = formater.format_date_in_arr(arr, ['CreationTime'])
 
+    # sort
+    arr = sort_cluster_list(arr)
+
     for item in arr:
         total =0
         actual_count = 0
@@ -34,6 +36,7 @@ def list():
         item['Counts'] = '%s / %s' % (actual_count,total)
         #item['Description'] =  formater.sub(item['Description'],10)
 
+
     result_cache.save(arr, 'Id', 'clusters')
 
     #print(white('RequestId: %s' % result.get('RequestId')))
@@ -47,12 +50,16 @@ def list():
 
     print(white('\n  type "%s c <Id|No.>" to show cluster detail\n' % (CMD)))
 
-def get(clusterId):
+def get(clusterId, descOnly=False, oplog=False):
     clusterId = result_cache.get(clusterId, 'clusters')
 
     print(white('exec: bcs c %s' % clusterId))
     result = client.get_cluster(clusterId)
 
+    if descOnly:
+        print(result)
+        return
+
     arr = [{
         'a': '%s: %s' % (blue('Id'), result.get('Id')),
         'b': '%s: %s' % (blue('Name'), result.get('Name')),
@@ -66,6 +73,14 @@ def get(clusterId):
     print('%s' % bold(magenta('Cluster:')))
     list2table.print_table(arr, ['a','b','c'], show_no=False, show_header=False)
 
+    # disks
+    disks = result.Configs.Disks
+    print(blue('Disks:'))
+    if disks.get('SystemDisk'):
+        print('  |--System Disk: %s (%s) %sGB' % ('/', blue(disks['SystemDisk']['Type']), disks['SystemDisk']['Size']) )
+    if disks.get('DataDisk') and disks['DataDisk'].get('MountPoint'):
+        print('  |--Data Disk: %s (%s) %sGB' % (disks['DataDisk']['MountPoint'], blue(disks['DataDisk']['Type']), disks['DataDisk']['Size'] ))
+    print('')
 
     # description
     if result.get('Description'):
@@ -101,7 +116,10 @@ def get(clusterId):
 
     for k in cols:
         t.append( (('  %s: %s' % (k[1](k[0]), metrics.get('%sCount' % k[0])) )) )
-        plen = metrics.get('%sCount' % k[0]) * PROGRESS_LEN/total_desired_vm_count
+        if total_desired_vm_count != 0:
+            plen =  metrics.get('%sCount' % k[0]) * PROGRESS_LEN/total_desired_vm_count
+        else:
+            plen = 0
         plen = int(plen)
         p.append(  str(k[1]('=' * plen)) if plen>0 else '' )
     print('  '.join(t))
@@ -117,11 +135,30 @@ def get(clusterId):
         for (k,v) in ud.items():
             print('  %s : %s' % (k,v))
 
-    # OperationLogs
-    print('%s:\n  %s' % (blue('Operation Logs'),   '\n  '.join(result.get('OperationLogs')) ))
 
     # print groups
     print('%s' % bold(magenta('Groups:')))
     list2table.print_table(groups, ['Name','VMCount','InstanceType/cpu/mem', 'ResourceType'])
 
+    # OperationLogs
+    if oplog:
+       print('%s:\n  %s' % (blue('Operation Logs'), '\n  '.join(result.get('OperationLogs'))))
+
+
     #print(result)
+
+def sort_cluster_list(arr):
+    others_arr = []
+    deleting_arr = []
+
+    for n in arr:
+        if n['State'] == 'Deleting':
+            deleting_arr.append(n)
+        else:
+            others_arr.append(n)
+
+    deleting_arr = formater.order_by(deleting_arr, ['CreationTime'], True)
+    others_arr = formater.order_by(others_arr, ['CreationTime'], True)
+
+    return deleting_arr + others_arr
+
