@@ -10,11 +10,7 @@ PROGRESS_LEN = 50
 def del_image(imageId, yes=False):
     arr = imageId.split(',')
 
-    t = []
-    if config.isGod():
-        t = util.parse_id_arr(arr, 'images')
-    else:
-        t = arr
+    t = util.parse_id_arr(arr, 'images',True)
 
     if yes:
         __batch_del(t)
