@@ -4,6 +4,7 @@ from ..util import client, oss_client, formater, list2table, result_cache, dag,
 from terminal import bold, magenta, white, blue, green, red, yellow, confirm
 from oss2.exceptions import NoSuchKey,NoSuchBucket
 from ..const import CMD,WIN,PY2
+import json
 
 PROGRESS_LEN = 50
 
@@ -99,7 +100,7 @@ def getJobDetail(jobId, descOnly):
         'b': '%s: %s' % (blue('Name'), result.get('Name')),
         'c': '%s: %s' % (blue('State'), formater.get_job_state(result.get('State')))
     }, {
-        "a": '%s: %s' % (blue('JobFailOnInstanceFail'), desc.get('JobFailOnInstanceFail')),
+        "a": '%s: %s    %s: %s' % (blue('JobFailOnInstanceFail'), desc.get('JobFailOnInstanceFail'),blue('AutoRelease'), desc.get('AutoRelease')),
         "b": '%s: %s' % (blue('Type'), desc.get('Type')),
         "c": '%s: %s' % (blue('Priority'), desc.get('Priority'))
     }, {
@@ -207,7 +208,7 @@ def getTaskDetail(jobId, taskName):
             print('    %s: %s' % (bold(k),v))
 
 
-    print('%s: %s' % ( blue('InputMappingConfig:'),formater.to_dict( taskDesc.Parameters.InputMappingConfig) ))
+    print('%s: %s' % ( blue('InputMappingConfig:'), json.dumps(formater.to_dict(taskDesc.Parameters.InputMappingConfig)) ))
     print('%s: %s' % ( blue('StdoutRedirectPath:'), taskDesc.Parameters.StdoutRedirectPath ))
     print('%s: %s' % ( blue('StderrRedirectPath:'), taskDesc.Parameters.StderrRedirectPath ))
 
