@@ -17,9 +17,10 @@ except:
 
 
 DEFAULT='DEFAULT'
+TIMEOUT=86400
 
 def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None, nodes=None,
-           force=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
+           force=False, auto_release=False, docker=None, pack=None, env=None, read_mount=None, write_mount=None, mount=None,
            file=None, user_data=None, priority=None, image=None,type=None, disk=None, lock=False, locale=None, show_json=False):
 
     if cmd == None and file == None  or cmd!=None and cmd.startswith('-'):
@@ -43,6 +44,7 @@ def submit(cmd=None, job_name=None, description=None, cluster=None, timeout=None
         'timeout': timeout,
         'nodes' : nodes,
         'force': force,
+        'auto_release': auto_release,
         'lock': lock,
         'locale': locale,
 
@@ -134,6 +136,8 @@ def fix_by_opt(desc, opt, check_cluster):
         desc['Priority'] = trans_priority(opt['priority'])
     if opt.get('force'):
         desc['JobFailOnInstanceFail'] = not opt['force']
+    if opt.get('auto_release'):
+        desc['AutoRelease'] = opt['auto_release']
 
 
 
@@ -227,6 +231,8 @@ def trans_file_to_job_desc(file, check_cluster):
             desc['Priority'] = trans_priority(default_options['priority'])
         if default_options.get('force'):
             desc['JobFailOnInstanceFail'] = not cf.getboolean(DEFAULT,'force')
+        if default_options.get('auto_release'):
+            desc['AutoRelease'] = cf.getboolean(DEFAULT, 'auto_release')
 
         if default_options.get('deps'):
             desc['DAG']['Dependencies'] = trans_deps(cf.get(DEFAULT,'deps'))
@@ -249,6 +255,8 @@ def trans_file_to_job_desc(file, check_cluster):
             desc['Priority'] = trans_priority(cf.get(sec,'priority'))
         if cf.has_option(sec,'force'):
             desc['JobFailOnInstanceFail'] = not cf.getboolean(sec,'force')
+        if cf.has_option(sec, 'auto_release'):
+            desc['AutoRelease'] = cf.getboolean(sec, 'auto_release')
         #################################
 
         ## extend by default options
@@ -387,9 +395,9 @@ def trans_nodes(n):
 def trans_timeout(n):
     try:
         n = int(n)
-        return n if n > 0 else 172800
+        return n if n > 0 else TIMEOUT
     except:
-        return 172800
+        return TIMEOUT
 
 
 
@@ -501,7 +509,7 @@ def build_tar_from_arr_and_upload(arr, oss_path):
 def gen_task_desc():
     return extend({
         "OutputMapping": {},
-        "Timeout": 172800,
+        "Timeout": TIMEOUT,
         "InputMapping": {},
         "LogMapping": {},
         "InstanceCount": 1,
@@ -533,6 +541,7 @@ def gen_job_desc():
         },
         "Description": "BatchCompute cli job",
         "JobFailOnInstanceFail": True,
+        "AutoRelease": False,
         "Priority": 1,
         "Type": "DAG",
         "Name": "cli-job"
