@@ -145,9 +145,11 @@ class Cli:
 
         get cluster info:
           1. %s c cls-6ki4fsea5ldlvsupbrk01q
-          2. %s c 1''' % (COMMAND, CMD, CMD, CMD),
+          2. %s c 1
+          3. %s c 1 -l''' % (COMMAND, CMD, CMD, CMD, CMD),
                                func=cluster.all)
-        cmd_clusters.option('-d, --description', MSG['cluster']['option']['description'])
+        cmd_clusters.option('-d,--description', MSG['cluster']['option']['description'])
+        cmd_clusters.option('-l,--log', MSG['cluster']['option']['oplog'])
         self.program.action(cmd_clusters)
 
 
@@ -308,11 +310,12 @@ class Cli:
         cmd_update_cluster = Command('update_cluster', alias=['uc'],
                                      arguments=['clusterId', 'groupName'],
                                      description=MSG['update_cluster']['description'],
-                                     usage='''Usage: %s update_cluster|uc <clusterId> <groupName> [option]
+                                     usage='''Usage: %s update_cluster|uc <clusterId> [groupName] [option]
 
           Examples:
 
-              1. %s uc cls-idxxx1 group1 -n 2   #update cluster set group1.DesiredVMCount=2''' % (COMMAND, CMD),
+              1. %s uc cls-idxxx1 group -n 2   # update cluster set group.DesiredVMCount=2
+              2. %s uc cls-idxxx1 -n 2         # ignore group name when it is 'group' ''' % (COMMAND, CMD, CMD),
                                      func=cluster_update.update)
         cmd_update_cluster.option("-y, --yes",  MSG['update_cluster']['option']['yes'])
         cmd_update_cluster.option("-n, --nodes <desiredVMCount>",  MSG['update_cluster']['option']['nodes'])
@@ -442,25 +445,29 @@ class Cli:
     Examples:
 
         1. %s sub "echo 'hello'" -n 3 -f                                                    # run this cmd on 3 machines(instances) in force mode
-        2. %s sub "echo 'hello'" -c img=%s                                         # use auto cluster
+        2. %s sub "echo 'hello'" -c img=%s                                         # use auto cluster, or -i %s
         3. %s sub "python main.py arg1 arg2" job_name -c cls-xxxxx -p ./my_program/         # set job name, use cluster id, pack a folder and upload
         4. %s sub "python /home/admin/test/main.py" -m oss://bucket/a/b/:/home/admin/test/  # mount an oss path to a local path
         5. %s sub "python test.py" -p test.py --docker myubuntu@oss://bucket/dockers/       # run in docker container
         6. %s sub --file job.cfg                    # submit a job from job.cfg''' % (
-                                 COMMAND, CMD, CMD, IMG_ID, CMD, CMD, CMD, CMD),
+                                 COMMAND, CMD, CMD, IMG_ID, IMG_ID, CMD, CMD, CMD, CMD),
                                  spliter='\n    -----%s----------------' % blue('quick cmd'),
                                  func=job_submit.submit)
 
 
         cmd_submit_job.option("-n, --nodes [machine_number]", MSG['submit']['option']['nodes'])
         cmd_submit_job.option("-f, --force", MSG['submit']['option']['force'])
+        cmd_submit_job.option("--auto_release", MSG['submit']['option']['auto_release'])
         cmd_submit_job.option("-d, --description [description]", MSG['submit']['option']['description'])
 
         cmd_submit_job.option("-p, --pack [folder_path]", MSG['submit']['option']['pack'])
         cmd_submit_job.option("--priority [priority]", MSG['submit']['option']['priority'])
 
-        cmd_submit_job.option("-t, --timeout [seconds]", MSG['submit']['option']['timeout'])
+        cmd_submit_job.option("--timeout [seconds]", MSG['submit']['option']['timeout'])
+
         cmd_submit_job.option("-c, --cluster [cluster]", MSG['submit']['option']['cluster'])
+        cmd_submit_job.option('-i, --image [imageId]', MSG['submit']['option']['image'])
+        cmd_submit_job.option('-t, --type [type]', MSG['submit']['option']['type'])
         cmd_submit_job.option("-e, --env [kv_pairs]", MSG['submit']['option']['env'])
         cmd_submit_job.option("-r, --read_mount [kv_pairs]",  MSG['submit']['option']['read_mount'])
         cmd_submit_job.option("-w, --write_mount [kv_pairs]", MSG['submit']['option']['write_mount'])
