@@ -1,9 +1,13 @@
 
 from .externals.command import Command
-from .action import project_create,project_build,project_submit,project_status,project_update,project_task_add
+from .action import project_create,project_build,project_submit,project_status,\
+    project_update
 from . import i18n_util
 
-from .const import *
+from .const import CMD,COMMAND
+
+IMG_ID = 'img-xxxxxx'
+INS_TYPE = 'ecs.s3.large'
 
 
 MSG=i18n_util.msg()
@@ -18,10 +22,11 @@ def init(cmd_project):
                              description=MSG['project']['create']['description'],
                              usage='''Usage: %s project|p <project_name> [location] [option]
 
-      Examples:
-          1. %s p create log-count                   # create an empty python type project
-          2. %s p create log-count ./ -t python      # create an python type project with template
-          3. %s p create log-count -j job-000020212  # create a project from exists job, witch jobId is job-000020212''' % (
+    Examples:
+
+        1. %s p create log-count                   # create an empty python type project
+        2. %s p create log-count ./ -t python      # create an python type project with template
+        3. %s p create log-count -j job-000020212  # create a project from exists job, witch jobId is job-000020212''' % (
                              COMMAND, CMD, CMD, CMD),
                              func=project_create.create)
     cmd_project_create.option("-t, --type [type]",
@@ -54,10 +59,11 @@ def init(cmd_project):
                             func=project_status.status,
     usage="""Usage: %s project|p status|st [option]
 
-      Example:
-          1. %s p st                 # show job descriptions, dag, and all task description
-          2. %s p st -d              # show dag only
-          3. %s p st -t [task_name]  # show the task description""" % (COMMAND, CMD, CMD, CMD) )
+    Example:
+
+        1. %s p st                 # show job descriptions, dag, and all task description
+        2. %s p st -d              # show dag only
+        3. %s p st -t [task_name]  # show the task description""" % (COMMAND, CMD, CMD, CMD) )
     cmd_project_status.option('-t, --task [task_name]', 'show description of a task')
     cmd_project_status.option('-d, --dag_only', 'show dag only')
     cmd_project.action(cmd_project_status)
@@ -70,11 +76,12 @@ def init(cmd_project):
                              description=MSG['project']['update']['description'],
                              usage='''Usage: %s project|p update [task] [option]
 
-      Examples:
-          1. %s p update -c img=%s:type=%s                   # update all tasks, set AutoCluster
-          2. %s p update -c cls-000010102                                       # update all tasks, set ClusterId
-          3. %s p update find -c cls-000010102                                  # update find task only
-          4. %s p update --docker oss://your-bucket/dockers/:localhost:5000/myubuntu  # update all task use docker ''' % (
+    Examples:
+
+        1. %s p update -c img=%s:type=%s                   # update all tasks, set AutoCluster
+        2. %s p update -c cls-000010102                                       # update all tasks, set ClusterId
+        3. %s p update find -c cls-000010102                                  # update find task only
+        4. %s p update --docker oss://your-bucket/dockers/:localhost:5000/myubuntu  # update all task use docker ''' % (
                              COMMAND, CMD, IMG_ID, INS_TYPE, CMD, CMD, CMD),
                              func=project_update.update)
     cmd_project_update.option("-c, --cluster [cluster]", MSG['project']['update']['option']['cluster'],
