@@ -7,7 +7,7 @@ CMD = 'bcs'
 
 LOCALE_SUPPORTED = ['en', 'zh', 'zh_CN']
 
-VERSION = '1.3.2'
+VERSION = '1.3.5'
 
 IT_MAP = {
     'ecs.t1.small': {'cpu': 1, 'memory': 1, 'name': 'ecs.t1.small'},
@@ -26,7 +26,15 @@ IT_MAP = {
     'bcs.b2.3xlarge': {'cpu': 16, 'memory': 32, 'name': 'bcs.b2.3xlarge'},
     'bcs.b4.xlarge':{'cpu': 8, 'memory': 32, 'name':'bcs.b4.xlarge'},
     'bcs.b4.3xlarge': {'cpu': 16, 'memory': 64, 'name': 'bcs.b4.3xlarge'},
-    'bcs.b4.5xlarge': {'cpu': 24, 'memory': 96, 'name': 'bcs.b4.5xlarge'}
+    'bcs.b4.5xlarge': {'cpu': 24, 'memory': 96, 'name': 'bcs.b4.5xlarge'},
+
+    'bcs.a2.4xlarge': {'cpu': 20, 'memory': 40, 'name': 'bcs.a2.4xlarge', 'disk': 400},
+    'bcs.b4.4xlarge': {'cpu': 20, 'memory': 80, 'name': 'bcs.b4.4xlarge', 'disk': 1000},
+
+    'ecs.n1.xlarge': {"cpu": 8, "memory": 16, "name": "ecs.n1.xlarge" },
+    'ecs.n1.3xlarge': {"cpu": 16, "memory": 32, "name": "ecs.n1.3xlarge" },
+    'ecs.n4.2xlarge': {"cpu": 8, "memory": 16, "name": "ecs.n4.2xlarge" },
+    'ecs.n4.4xlarge': {"cpu": 16, "memory": 32, "name": "ecs.n4.4xlarge" }
 }
 #
 # IT = {
