@@ -42,7 +42,8 @@ def getJSON():
         "cluster": {
             "description": 'show cluster list, show cluster detail.',
             "option": {
-                'description': 'show description of the cluster'
+                'description': 'show description of the cluster',
+                'oplog' :'show operation logs. It works for showing cluster detail only.'
             }
         },
         "job": {
@@ -156,7 +157,7 @@ def getJSON():
                 IMG_ID, INS_TYPE, CMD, CMD, CMD),
                 'pack': "optional,pack the files in the program_folder into worker.tar.gz, and upload to oss, if you don't set this option, no pack, no upload",
                 'priority': 'optional,int,job priority,default:0\n',
-                'timeout': "optional,job would failed if it had expired, default: 172800(2 days)",
+                'timeout': "optional,job would failed if it had expired, default: 86400(1 days)",
                 'image': """optional, set autoCluster image id, priority is higher than auto_cluster string set by cluster option,
                                       and it doesn't work when clusterId is set by cluster option""",
                 'type': """optional, set autoCluster instance type, priority is higher than auto_cluster string set by cluster option,
@@ -164,6 +165,7 @@ def getJSON():
                 'nodes': "optional,the number of machines you needed to run the program, default: 1",
                 'description': 'optional,set job description',
                 'force': "optional,job don't fail when instance were failed, default: job fail when even one instance were failed",
+                'auto_release': "optional, job will be released (deleted) when finished(job.state=='finished')",
                 'env': "optional,set environment variables, format: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """optional,mount a oss path to local file system in read-only mode, kv-pairs, multi-supported,
                                       format: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
