@@ -60,7 +60,8 @@ def __get_json():
         "cluster": {
             "description": '获取集群列表, 获取集群详情.',
             "option": {
-                'description': '获取集群描述JSON'
+                'description': '获取集群描述JSON',
+                'oplog': '显示操作日志, 获取集群详情有效'
             }
         },
         "job": {
@@ -173,12 +174,13 @@ def __get_json():
                 IMG_ID, INS_TYPE, CMD, CMD, CMD),
                 'pack': "可选,打包指定目录下的文件,并上传到OSS, 如果没有指定这个选项则不打包不上传",
                 'priority': '可选,int类型,指定作业优先级,默认:0\n',
-                'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 172800(单位秒,表示2天)",
+                'timeout': "可选,超时时间(如果实例运行时间超时则失败), 默认: 86400(单位秒,表示1天)",
                 'image': "可选, AutoCluster使用的imageId, 优先级高于cluster中的AutoCluster字符串配置, 设置cluster为clusterId时该项无效",
                 'type': "可选, AutoCluster使用的instanceType, 优先级高于cluster中的AutoCluster字符串配置, 设置cluster为clusterId时该项无效",
                 'nodes': "可选,需要运行程序的机器数, 默认: 1",
                 'description': '可选,设置作业描述',
                 'force': "可选,当instance失败时job不失败, 默认:当instance失败时job也失败",
+                'auto_release': "可选,当job运行成功(state=='Finished')后自动被释放(删除)掉",
                 'env': "可选,设置环境变量, 格式: <k>:<v>[,<k2>:<v2>...]",
                 'read_mount': """可选,只读模式挂载配置, 格式: <oss_path>:<dir_path>[,<oss_path2>:<dir_path2>...],
                                       如: oss://bucket/key:/home/admin/ossdir 表示将oss的路径挂载到本地目录""",
