@@ -1,5 +1,7 @@
 import json
 import os
+from terminal import white
+from . import config
 
 usr_home = os.path.expanduser('~')
 cfg_dir = os.path.join(usr_home, '.batchcompute')
@@ -18,7 +20,6 @@ def save(arr, col, title):
         f.write(s)
 
 def get_index(index, title):
-
     cli_path = os.path.join(cfg_dir, 'clicache_%s.json' % title)
 
     if(os.path.exists(cli_path)):
@@ -26,16 +27,26 @@ def get_index(index, title):
             obj = json.loads(f.read())
         if obj.get('title') == title:
             arrlen = len(obj.get('data'))
-            index = min(index, arrlen-1)
-            index = max(index, 0)
+
+            if index > arrlen:
+                print(white('%s > %s(cache length), use %s' % (index, arrlen, arrlen)))
+                index = arrlen-1
+            elif index < 1:
+                print(white('%s < 1, use 1' % index))
+                index = 0
+            else:
+                index -= 1
+
             return obj['data'][index]
     return None
 
 
-def get(id, title):
+def get(id, title, needCheckGod=False):
+    if needCheckGod and not config.isGod() and '-' not in id:
+        raise Exception('Invalid id: %s' % id)
+
     try:
         i = int(id)
-        i = i-1
         v = get_index(i, title)
         return v or id
     except:
