@@ -8,14 +8,12 @@ from ..const import CMD
 import re
 
 
-def parse_id_arr(arr, type='jobs'):
+def parse_id_arr(arr, type='jobs', needCheckGod=False):
     t=[]
     arr = _parse_shot_id(arr)
 
-    print(arr)
-
     for item in arr:
-        id = result_cache.get(item, type)
+        id = result_cache.get(item, type, needCheckGod)
         t.append(id)
     return t
 
